@@ -28,6 +28,7 @@ class MintInput:
 
 	def __init__(self):
 		self.glade  = '/usr/lib/linuxmint/mintinput/mintinput.glade'
+#		self.glade = 'mintinput.glade'
 		self.builder = gtk.Builder()
 		self.builder.add_from_file(self.glade)
 
@@ -53,9 +54,6 @@ class MintInput:
 		self.builder.get_object("image_mouse").set_from_pixbuf(self.mouse)
 		self.builder.get_object("image_keyboard").set_from_pixbuf(self.keys)
 
-		self.builder.get_object("button_layout").set_label(_("Select layout"))
-		self.builder.get_object("button_layout").connect("clicked", self.layout_cb)
-
 		# keyboard delay
 		self.builder.get_object("label_delay").set_label(_("Delay"))
 		delay = self.builder.get_object("scale_delay")
@@ -77,11 +75,14 @@ class MintInput:
 		self.builder.get_object("checkbutton_lhd").set_label(_("Left Handed"))
 		self.builder.get_object("checkbutton_vertical").set_label(_("Vertical Scrolling"))
 		self.builder.get_object("checkbutton_horizontal").set_label(_("Horizontal Scrolling"))
+		self.builder.get_object("checkbutton_tap").set_label(_("Tap-to-Click Enabled"))
 		self.builder.get_object("checkbutton_touchpad").set_active(True)
 		self.builder.get_object("checkbutton_touchpad").connect("clicked", self.touchpad_cb)
 		self.builder.get_object("checkbutton_vertical").set_active(True)
 		self.builder.get_object("checkbutton_vertical").connect("clicked", self.touchpad_vertical)
 		self.builder.get_object("checkbutton_horizontal").connect("clicked", self.touchpad_horizontal)
+		self.builder.get_object("checkbutton_tap").set_active(True)
+		self.builder.get_object("checkbutton_tap").connect("clicked", self.touchpad_tap)
 
 		# accel.
 		self.builder.get_object("label_acceleration").set_label(_("Acceleration"))
@@ -113,9 +114,9 @@ class MintInput:
 		horiz = str("synclient HorizEdgeScroll=%d" % (int(w.get_active())))
 		os.system(horiz)
 
-	''' show keyboard layout chooser '''
-	def layout_cb(self, w):
-		os.system("skl &")
+	def touchpad_tap(self, w):
+		tap = str("synclient TapButton1=$d" % (int(w.get_active())))
+		os.system(tap)
 
 	''' apply all settings '''
 	def apply_cb(self, widget):
@@ -142,6 +143,10 @@ class MintInput:
 			w = self.builder.get_object("checkbutton_touchpad")
 			pad = str("synclient TouchPadOff=%d" % (int(not w.get_active())))
 
+			# touchpad tapping
+			t = self.builder.get_object("checkbutton_tap")
+			tap = str("synclient TapButton1=%d" % (int(t.get_active())))
+
 			# vertical scrolling?
 			v = self.builder.get_object("checkbutton_vertical")
 			vert = str("synclient VertEdgeScroll=%d" % (int(v.get_active())))
@@ -162,6 +167,7 @@ class MintInput:
 			os.system('echo \"' + pad + '\" >> $HOME/.linuxmint/sms')
 			os.system('echo \"' + vert + '\" >> $HOME/.linuxmint/sms')
 			os.system('echo \"' + horiz + '\" >> $HOME/.linuxmint/sms')
+			os.system('echo \"' + tap + '\" >> $HOME/.linuxmint/sms')
 			os.system('echo \'xmodmap -e \"' + paw + '\"\' >> $HOME/.linuxmint/sms')
 			os.system('echo \"xset m ' + str(accel) + ' ' + str(threshold) + '\" >> $HOME/.linuxmint/sms')
 			os.system("mintinput1")
